@@ -92,7 +92,18 @@ static GList* nautilus_get_property_pages (NautilusPropertyPageProvider *provide
 
 	// Ara obtenim la URI de Nautilus
 	uri = nautilus_file_info_get_uri (file);
+
+    if (uri == NULL)
+    {
+        return NULL;
+    }
+
 	GnomeVFSURI* guri = gnome_vfs_uri_new(uri);
+
+    if (guri == NULL)
+    {
+        return NULL;
+    }
 	// i comprovem que s local
 	const gchar* scheme = gnome_vfs_uri_get_scheme(guri);
 	if (strcmp(scheme, "file") != 0)
