@@ -20,29 +20,37 @@
 #include <gtkmm.h>
 #include "eiciel_container.hpp"
 #include <gettext.h>
+#include <gnome.h>
 
 int main(int argc, char* argv[])
 {
 #ifdef ENABLE_NLS
-	setlocale(LC_ALL, "");
+    setlocale(LC_ALL, "");
     bindtextdomain("eiciel", DATADIR "/locale");
     // textdomain("eiciel");
-    
+
     // Volem les traduccions en UTF-8 (independentment del
     // format usat per a traduir)
     bind_textdomain_codeset ("eiciel", "UTF-8");
 #endif
-	Gtk::Main kit(argc, argv);
 
-	EicielContainer w;
+    GnomeProgram *my_app;
+    my_app = gnome_program_init(PACKAGE, VERSION,
+            LIBGNOMEUI_MODULE, argc, argv, 
+            GNOME_PARAM_HUMAN_READABLE_NAME, "Eiciel",
+            GNOME_PARAM_APP_DATADIR, DATADIR,
+            NULL);
+    Gtk::Main kit(argc, argv);
 
-	if (argc > 1)
-	{
-		w.obrirFitxer(argv[1]);
-	}
+    EicielContainer w;
 
-	kit.run(w);
+    if (argc > 1)
+    {
+        w.obrirFitxer(argv[1]);
+    }
 
-	return 0;
+    kit.run(w);
+
+    return 0;
 }
 
